def saludar():
  print("Hola, te saludo desde saludos.saludar():")  

def prueba():
  print("Esto es una de la nueva versión")

class Saludo:
    def __init__(self):
       print("Te saludo desde Saludo.__init__()")


if __name__ == '__main__':
    saludar()


from setuptools import setup

setup(
    name="Mensajes",
    versio="2.0",
    description="un paquete para saludar y despedir",
    author="jhonatan Rincon",
    author_email="jeramix92@gmail.com",
    url="https://www.hektor.dev",
    packages=["Mensajes","Mensajes.hola","Mensajes.adios"],
    scripts=["Test.py"]
)



# import Saludos este es para importar todo el script
# from Saludos import saludar si tenemos más definiciones podemos agregarlas con comas
# from Saludos import saludar, Saludo
# from Saludos import * para importar todas las funciones o clases del módulo
from Mensajes.hola.Saludos import *
from Mensajes.adios.despedida import *

# Saludos.saludar()
saludar()
Saludo()

despedir()
Despedida()